@@ -14,6 +14,8 @@ use switchboard_protos::protos::fulfillment_manager::mod_FulfillmentManagerState
 use switchboard_protos::protos::switchboard_account_types::SwitchboardAccountType;
 use std::convert::TryInto;
 
+pub mod flat_aggregator_result_generated;
+pub use flat_aggregator_result_generated::*;
 pub type PubkeyBuffer = [u8; 32];
 
 #[derive(BorshSerialize, BorshDeserialize, Debug, Default, PartialEq, Clone)]
